import { type ICalendarEventSourceSchema } from "@leight/calendar";
import { type IFilterStoreProps, type IUseFilterState } from "@leight/filter";
import { type InferSelectors } from "@leight/mantine";
import { type ISourceStoreProps, type IUseSourceState } from "@leight/source";
import { Container } from "@mantine/core";
import { type ComponentProps, type ReactNode } from "react";
declare const useStyles: (params: void, options?: import("@mantine/core").UseStylesOptions<string> | undefined) => {
    classes: {
        calendar: string;
        calendarGrid: string;
        controlsGrid: string;
        controls: string;
        controlsLeft: string;
        controlsMiddle: string;
        controlsRight: string;
        controlsPrefix: string;
        controlsSuffix: string;
        header: string;
        cell: string;
        monthCell: string;
        yearCell: string;
        row: string;
        currentMonth: string;
        currentYear: string;
        currentWeek: string;
        currentDay: string;
        inRange: string;
        outOfRange: string;
    };
    cx: (...args: any) => string;
    theme: import("@mantine/core").MantineTheme;
};
export type ICalendarStyles = InferSelectors<typeof useStyles>;
export type ICalendarComponent<TSourceSchema extends ICalendarEventSourceSchema> = ((props: ICalendarComponent.IRenderProps<TSourceSchema>) => ReactNode) | ReactNode;
export declare namespace ICalendarComponent {
    interface IRenderProps<TSourceSchema extends ICalendarEventSourceSchema> {
        classes: ICalendarStyles;
        source?: ISourceStoreProps<TSourceSchema>["StoreProps"];
        filter?: IFilterStoreProps<TSourceSchema["FilterSchema"]>["StoreProps"];
    }
}
export interface ICalendarShellEvents<TSourceSchema extends ICalendarEventSourceSchema> {
    schema: TSourceSchema["EntitySchema"];
    useSource: IUseSourceState<TSourceSchema>;
    useFilter: IUseFilterState<TSourceSchema["FilterSchema"]>;
}
export interface ICalendarShellProps<TSourceSchema extends ICalendarEventSourceSchema> extends Omit<ComponentProps<typeof Container>, "children"> {
    events?: ICalendarShellEvents<TSourceSchema>;
    withControls?: boolean;
    controlsTopLeft?: ICalendarComponent<TSourceSchema>;
    controlsTopMiddle?: ICalendarComponent<TSourceSchema>;
    controlsTopRight?: ICalendarComponent<TSourceSchema>;
    controlsBottomLeft?: ICalendarComponent<TSourceSchema>;
    controlsBottomMiddle?: ICalendarComponent<TSourceSchema>;
    controlsBottomRight?: ICalendarComponent<TSourceSchema>;
    children: ICalendarComponent<TSourceSchema>;
}
/**
 * Styled shell for Calendar.
 */
export declare const CalendarShell: <TSourceSchema extends ICalendarEventSourceSchema = ICalendarEventSourceSchema>({ events, withControls, controlsTopLeft, controlsTopMiddle, controlsTopRight, controlsBottomLeft, controlsBottomMiddle, controlsBottomRight, children, ...props }: ICalendarShellProps<TSourceSchema>) => JSX.Element;
export {};
//# sourceMappingURL=CalendarShell.d.ts.map